@@ -1,6 +1,6 @@
 from django import forms
 
-from ...models.collection import FileItem, ImageItem
+from ...models.collection import FileItem, SVGItem, ImageItem
 from .base import ChangeFileResourceDialogBase
 
 
@@ -10,6 +10,17 @@ class ChangeFileItemDialog(ChangeFileResourceDialogBase):
         fields = ["new_name", "display_name"]
 
 
+class ChangeSVGItemDialog(ChangeFileResourceDialogBase):
+    class Meta:
+        model = SVGItem
+        fields = ["new_name", "display_name", "title", "description"]
+        widgets = {
+            "description": forms.Textarea(attrs={
+                "rows": 2
+            })
+        }
+
+
 class ChangeImageItemDialog(ChangeFileResourceDialogBase):
     class Meta:
         model = ImageItem
