@@ -1,4 +1,5 @@
 import os
+import warnings
 from typing import Sequence, Union
 
 import magic
@@ -13,6 +14,7 @@ from .utils import filesizeformat, parse_filesize, remove_dulpicates
 __all__ = [
     "ExtensionValidator",
     "MimeTypeValidator",
+    "MaxSizeValidator",
     "SizeValidator",
     "ImageMinSizeValidator",
     "ImageMaxSizeValidator",
@@ -72,7 +74,7 @@ class MimeTypeValidator:
 
 
 @deconstructible
-class SizeValidator:
+class MaxSizeValidator:
     message = _("File `%(name)s` is too large. Maximum file size is %(limit_value)s.")
     code = "size_limit"
 
@@ -98,6 +100,16 @@ class SizeValidator:
         return "{}: {}".format(_("Maximum file size"), filesizeformat(self.limit_value))
 
 
+class SizeValidator(MaxSizeValidator):
+    def __init__(self, *args, **kwargs):
+        warnings.warn(
+            "SizeValidator is deprecated in favor of MaxSizeValidator",
+            DeprecationWarning,
+            stacklevel=2
+        )
+        super().__init__(*args, **kwargs)
+
+
 @deconstructible
 class ImageMinSizeValidator:
     error_messages = {
@@ -152,7 +164,10 @@ class ImageMinSizeValidator:
             if self.height_limit:
                 return "{}: {}".format(
                     _("Minimum dimensions"),
-                    _("%sx%s pixels") % (self.width_limit, self.height_limit)
+                    _("%(min_width)sx%(min_height)s pixels") % {
+                        "min_width": self.width_limit,
+                        "min_height": self.height_limit
+                    }
                 )
             else:
                 return "{}: {}".format(_("Minimum image width"), _("%s pixels") % self.width_limit)
@@ -214,7 +229,10 @@ class ImageMaxSizeValidator:
             if self.height_limit:
                 return "{}: {}".format(
                     _("Maximum dimensions"),
-                    _("%sx%s pixels") % (self.width_limit, self.height_limit),
+                    _("%(max_width)sx%(max_height)s pixels") % {
+                        "max_width": self.width_limit,
+                        "max_height": self.height_limit
+                    },
                 )
             else:
                 return "{}: {}".format(_("Maximum image width"), _("%s pixels") % self.width_limit)
